@@ -74,6 +74,8 @@ struct DownloaderViewPrivate
 	GtkTreeModel *model;
 	gboolean show_details;
 
+	gboolean deleting;
+
 	/* Widgets */
 	GtkWidget *treeview;
 	GtkWidget *details_file;
@@ -115,9 +117,9 @@ struct _Download
 
 	guint  elapsed;		/* seconds */
 	guint  remaining;	/* seconds (G_MAXUINT if indeterminate) */
-	guint  speed;		/* bytes per second */
-	gulong size_total;	/* bytes (G_MAXULONG if indeterminate) */
-	gulong size_done;	/* bytes */
+	guint64  speed;		/* bytes per second */
+	guint64 size_total;	/* bytes (G_MAXUINT64 if indeterminate) */
+	guint64 size_done;	/* bytes */
 	gfloat progress;	/* 0.0 .. 1.0 (or < 0 if indeterminate) */
 
 	gboolean can_pause;
@@ -373,6 +375,8 @@ static void
 downloader_view_init (DownloaderView *dv)
 {
         dv->priv = DOWNLOADER_VIEW_GET_PRIVATE (dv);
+
+	dv->priv->deleting = FALSE;
 	
 	downloader_view_build_ui (dv);
 
@@ -630,7 +634,7 @@ downloader_view_set_download_info (DownloaderViewPrivate *priv,
 			    -1);
 	
 	/* Total */
-	if (details->size_total < G_MAXULONG)
+	if (details->size_total < G_MAXUINT64)
 	{
 		size = gnome_vfs_format_file_size_for_display (details->size_total);
 	}
@@ -707,7 +711,7 @@ downloader_view_add_download (DownloaderView *dv,
 	details->elapsed = 0;
 	details->remaining = G_MAXUINT;
 	details->speed = 0;
-	details->size_total = G_MAXULONG;
+	details->size_total = G_MAXUINT64;
 	details->size_done = 0;
 	details->progress = -1;
 	dv->priv->show_details = FALSE;
@@ -718,6 +722,8 @@ downloader_view_add_download (DownloaderView *dv,
 	path = gtk_tree_model_get_path (GTK_TREE_MODEL(dv->priv->model), &iter);
 	details->ref = gtk_tree_row_reference_new
 		(GTK_TREE_MODEL (dv->priv->model), path);
+	gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(dv->priv->treeview), path, NULL,
+		FALSE, 0.0, 0.0);
 	gtk_tree_path_free (path);
 
 	gtk_list_store_set (GTK_LIST_STORE (dv->priv->model),
@@ -753,7 +759,15 @@ downloader_view_remove_download (DownloaderView *dv,
 				 &iter, path);
 	gtk_tree_path_free (path);
 
-	gtk_list_store_remove (GTK_LIST_STORE (dv->priv->model), &iter);
+	/*
+	 * If we're deleting the dialog, then we don't need to remove the
+	 * row, and we'll actually cause problems if we do because this
+	 * call is made during a foreach iteration over the store.
+	 */
+	if (!dv->priv->deleting)
+	{
+		gtk_list_store_remove (GTK_LIST_STORE (dv->priv->model), &iter);
+	}
 
         galeon_dialog_get_value (GALEON_DIALOG(dv), PROP_KEEP_OPEN, &keep_open);
 	
@@ -772,9 +786,9 @@ void
 download_set_progress (Download	*details,
 		       guint	 elapsed,
 		       guint	 remaining,
-		       guint	 speed,
-		       gulong	 size_done,
-		       gulong	 size_total)
+		       guint64	 speed,
+		       guint64	 size_done,
+		       guint64	 size_total)
 {
 	details->elapsed = elapsed;
 	details->remaining = remaining;
@@ -790,14 +804,14 @@ download_set_progress (Download	*details,
 }
 
 void
-download_set_size_total (DownloadDetails *details, gulong size_total)
+download_set_size_total (DownloadDetails *details, guint64 size_total)
 {
 	DownloaderView *dv;
 	GtkTreePath *path;
 	GtkTreeIter  iter;
 
 	details->size_total = size_total;
-	if (size_total > 0 && size_total < G_MAXULONG)
+	if (size_total > 0 && size_total < G_MAXUINT64)
 	{
 		details->progress = (gfloat)details->size_done / size_total;
 	}
@@ -864,7 +878,7 @@ download_resumed (Download *self)
 void
 download_completed (Download *self)
 {
-	if (self->size_total < G_MAXULONG)
+	if (self->size_total < G_MAXUINT64)
 	{
 		self->size_done = self->size_total;
 	}
@@ -1157,7 +1171,7 @@ delete_pending_foreach (GtkTreeModel *model,
 			gpointer      user_data)
 {
 	DownloadDetails *details;
-	
+
 	gtk_tree_model_get (model, iter, COL_DETAILS, &details, -1);
 	g_return_val_if_fail (details != NULL, TRUE);
 
@@ -1195,7 +1209,9 @@ download_dialog_delete_cb (GtkWidget *window, GdkEventAny *event,
 	/* do the appropriate thing */
 	if (choice == GTK_RESPONSE_YES)
 	{
+		dv->priv->deleting = TRUE;
 		gtk_tree_model_foreach (dv->priv->model, delete_pending_foreach, NULL);
+		dv->priv->deleting = FALSE;
 		return FALSE;
 	}
 
