@@ -109,16 +109,16 @@ egg_toolbars_model_to_xml (EggToolbarsModel *t)
   tl = t->priv->toolbars;
 
   xmlIndentTreeOutput = TRUE;
-  doc = xmlNewDoc ("1.0");
-  doc->children = xmlNewDocNode (doc, NULL, "toolbars", NULL);
+  doc = xmlNewDoc (BAD_CAST "1.0");
+  doc->children = xmlNewDocNode (doc, NULL, BAD_CAST "toolbars", NULL);
 
   for (l1 = tl->children; l1 != NULL; l1 = l1->next)
     {
       xmlNodePtr tnode;
       EggToolbarsToolbar *toolbar = l1->data;
 
-      tnode = xmlNewChild (doc->children, NULL, "toolbar", NULL);
-      xmlSetProp (tnode, "name", toolbar->name);
+      tnode = xmlNewChild (doc->children, NULL, BAD_CAST "toolbar", NULL);
+      xmlSetProp (tnode, BAD_CAST "name", BAD_CAST toolbar->name);
 
       for (l2 = l1->children; l2 != NULL; l2 = l2->next)
 	{
@@ -127,16 +127,16 @@ egg_toolbars_model_to_xml (EggToolbarsModel *t)
 
 	  if (item->separator)
 	    {
-	      node = xmlNewChild (tnode, NULL, "separator", NULL);
+	      node = xmlNewChild (tnode, NULL, BAD_CAST "separator", NULL);
 	    }
 	  else
 	    {
 	      char *data;
 
-	      node = xmlNewChild (tnode, NULL, "toolitem", NULL);
+	      node = xmlNewChild (tnode, NULL, BAD_CAST "toolitem", NULL);
 	      data = egg_toolbars_model_get_item_data (t, item->type, item->id);
-	      xmlSetProp (node, "type", item->type);
-	      xmlSetProp (node, "name", data);
+	      xmlSetProp (node, BAD_CAST "type", BAD_CAST item->type);
+	      xmlSetProp (node, BAD_CAST "name", BAD_CAST data);
 	      g_free (data);
 	    }
 	}
@@ -213,7 +213,7 @@ egg_toolbars_model_save (EggToolbarsModel *t,
 
   doc = egg_toolbars_model_to_xml (t);
   root = xmlDocGetRootElement (doc);
-  xmlSetProp (root, "version", version);
+  xmlSetProp (root, BAD_CAST "version", BAD_CAST version);
   safe_save_xml (xml_file, doc);
   xmlFreeDoc (doc);
 }
@@ -364,31 +364,31 @@ parse_item_list (EggToolbarsModel *t,
 {
   while (child)
     {
-      if (xmlStrEqual (child->name, "toolitem"))
+      if (xmlStrEqual (child->name, BAD_CAST "toolitem"))
 	{
 	  xmlChar *name, *type;
 	  char *id;
 
-	  name = xmlGetProp (child, "name");
-	  type = xmlGetProp (child, "type");
+	  name = xmlGetProp (child, BAD_CAST "name");
+	  type = xmlGetProp (child, BAD_CAST "type");
           if (type == NULL)
             {
-              type = xmlStrdup (EGG_TOOLBAR_ITEM_TYPE);
+              type = xmlCharStrdup (EGG_TOOLBAR_ITEM_TYPE);
             }
 
 	  if (name != NULL && name[0] != '\0' && type != NULL)
 	    {
-              id = egg_toolbars_model_get_item_id (t, type, name);
+              id = egg_toolbars_model_get_item_id (t, (const char *)type, (const char *)name);
 	      if (id != NULL)
 	        {
-	          egg_toolbars_model_add_item (t, position, -1, id, type);
+	          egg_toolbars_model_add_item (t, position, -1, id, (const char *)type);
                 }
               g_free (id);
             }
 	  xmlFree (name);
           xmlFree (type);
 	}
-      else if (xmlStrEqual (child->name, "separator"))
+      else if (xmlStrEqual (child->name, BAD_CAST "separator"))
 	{
 	  egg_toolbars_model_add_separator (t, position, -1);
 	}
@@ -424,18 +424,18 @@ parse_toolbars (EggToolbarsModel *t,
 {
   while (child)
     {
-      if (xmlStrEqual (child->name, "toolbar"))
+      if (xmlStrEqual (child->name, BAD_CAST "toolbar"))
 	{
 	  xmlChar *name;
 	  xmlChar *style;
 	  int position;
 
-	  name = xmlGetProp (child, "name");
-	  position = egg_toolbars_model_add_toolbar (t, -1, name);
+	  name = xmlGetProp (child, BAD_CAST "name");
+	  position = egg_toolbars_model_add_toolbar (t, -1, (const char *) name);
 	  xmlFree (name);
 
-	  style = xmlGetProp (child, "style");
-	  if (style && xmlStrEqual (style, "icons-only"))
+	  style = xmlGetProp (child, BAD_CAST "style");
+	  if (style && xmlStrEqual (style, BAD_CAST "icons-only"))
 	    {
 	      /* FIXME: use toolbar position instead of 0 */
 	      egg_toolbars_model_set_flags (t, 0, EGG_TB_MODEL_ICONS_ONLY);
