@@ -150,6 +150,7 @@
 #include <libgnomevfs/gnome-vfs-mime.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 
+#include "AutoJSContextStack.h"
 #include "ContentHandler.h"
 #include "GaleonUtils.h"   /* GaleonUtils::FindGtkParent */
 #include "ProgressListener.h" /* for BuildDownloadPath */
@@ -314,6 +315,11 @@ NS_IMETHODIMP GContentHandler::PromptForSaveToFile(
 		if (NS_SUCCEEDED (rv)) return rv;
 	}
 
+	nsresult rv;
+	AutoJSContextStack stack;
+	rv = stack.Init ();
+	if (NS_FAILED (rv)) return rv;
+
 	GulFileChooser *dialog;
 	dialog = gul_file_chooser_new (_("Save"), parentWindow,
 					GTK_FILE_CHOOSER_ACTION_SAVE,
@@ -559,8 +565,13 @@ NS_METHOD GContentHandler::ProcessMimeInfo (void)
 		nsMemory::Free(filename);
 #endif
 
+#ifdef HAVE_GNOME_VFS_GET_MIME_TYPE_FOR_NAME
+		mMimeType.Assign(gnome_vfs_get_mime_type_for_name
+				 (uriFileName.get()));
+#else
 		mMimeType.Assign(gnome_vfs_mime_type_from_name
 				 (uriFileName.get()));
+#endif
 	}
 
 	return NS_OK;
@@ -842,6 +853,11 @@ mime_ask_dialog_open_clicked_cb (GtkButton *button, MimeAskActionDialog *dialog)
 	}
 	else
 	{	
+		nsresult rv;
+		AutoJSContextStack stack;
+		rv = stack.Init ();
+		if (NS_FAILED (rv)) return;
+
 		mime_ask_dialog_download_cancel(dialog);
 		galeon_embed_utils_nohandler_dialog_run(dialog->mParent);
 	}
@@ -887,6 +903,11 @@ NS_IMETHODIMP MiniProgressListener::OnStatusChange(nsIWebProgress *aWebProgress,
 {
 	if (NS_SUCCEEDED (aStatus)) return NS_OK;
 
+	nsresult rv;
+	AutoJSContextStack stack;
+	rv = stack.Init ();
+	if (NS_FAILED (rv)) return rv;
+
 	/* When the save fails, the mozilla code will call this, and
 	 * after this point, the launcher isn't valid for some reason
 	 * so we need to display an error, and get out of this code
@@ -944,5 +965,15 @@ NS_IMETHODIMP MiniProgressListener::OnProgressChange64(nsIWebProgress *aWebProgr
 {
     return NS_ERROR_NOT_IMPLEMENTED;
 }
+
+#ifdef HAVE_NSIWEBPROGRESSLISTENER2_ONREFRESHATTEMPTED
+NS_IMETHODIMP MiniProgressListener::OnRefreshAttempted(nsIWebProgress *aWebProgress,
+						nsIURI *aRefreshURI, PRInt32 aMillis,
+						PRBool aSameURI, PRBool *_retval)
+{
+    return NS_ERROR_NOT_IMPLEMENTED;
+}
+#endif
+
 #endif
 
