@@ -2030,12 +2030,29 @@ GDOMPopupEventListener::HandleEvent (nsIDOMEvent* aDOMEvent)
 		do_QueryInterface(aDOMEvent);
 	NS_ENSURE_TRUE (popupEvent, NS_ERROR_FAILURE);
 
+	GulCString spec;
+#ifdef HAVE_NSIDOMPOPUPBLOCKEDEVENT_GETREQUESTINGWINDOW
+	nsCOMPtr<nsIDOMWindow> requesterWindow;
+	popupEvent->GetRequestingWindow(getter_AddRefs(requesterWindow));
+	NS_ENSURE_TRUE (requesterWindow, NS_ERROR_FAILURE);
+
+	nsCOMPtr<nsIDOMDocument> requesterDocument;
+	requesterWindow->GetDocument(getter_AddRefs(requesterDocument));
+	NS_ENSURE_TRUE (requesterDocument, NS_ERROR_FAILURE);
+
+	nsCOMPtr<nsIDOM3Document> doc(do_QueryInterface(requesterDocument));
+	NS_ENSURE_TRUE (doc, NS_ERROR_FAILURE);
+
+	GulString uSpec;
+	rv = doc->GetDocumentURI(uSpec);
+	spec = uSpec;
+#else
 	nsCOMPtr<nsIURI> requesterURI;
 	popupEvent->GetRequestingWindowURI(getter_AddRefs(requesterURI));
 	NS_ENSURE_TRUE (requesterURI, NS_ERROR_FAILURE);
 
-	GulCString spec;
 	rv = requesterURI->GetSpec(spec);
+#endif
 	NS_ENSURE_SUCCESS (rv, rv);
 	NS_ENSURE_FALSE (spec.IsEmpty(), NS_ERROR_FAILURE);
 
