@@ -227,7 +227,11 @@ nsresult
 MozillaPrivate::GetCompatibilityMode (nsIDOMNSDocument *aDoc,
 				      EmbedPageRenderMode *aMode)
 {
+#ifdef HAVE_NSIDOCUMENT_GETCOMPATIBILITYMODE
+	nsCOMPtr<nsIDocument> htmlDoc = do_QueryInterface (aDoc);
+#else
 	nsCOMPtr<nsIHTMLDocument> htmlDoc = do_QueryInterface (aDoc);
+#endif
 	NS_ENSURE_TRUE(htmlDoc, NS_ERROR_FAILURE);
 
 	nsCompatibility compat = htmlDoc->GetCompatibilityMode();
