@@ -22,8 +22,8 @@
 #include <config.h>
 #endif
 
-#define MOZILLA_INTERNAL_API
 #include <nscore.h>
+#define MOZILLA_INTERNAL_API
 #include <nsIServiceManager.h>
 #undef MOZILLA_INTERNAL_API
 #include <nsCOMPtr.h>
@@ -172,6 +172,16 @@ GMyportalProtocolHandler::AllowPort(PRInt32 port,
 	return NS_OK;
 }
 
+#ifdef HAVE_NSIABOUTMODULE_GETURIFLAGS
+/* unsigned long getURIFlags (in nsIURI aURI); */
+NS_IMETHODIMP
+GMyportalProtocolHandler::GetURIFlags(nsIURI *aURI,
+                                      PRUint32 *_retval)
+{
+	*_retval = 0;
+	return NS_OK;
+}
+#endif
 
 // ------------------------------------------------------------
 /**
