@@ -664,6 +664,18 @@ NS_IMETHODIMP GProgressListener::
     return NS_OK;
 }
 
+#ifdef HAVE_NSIWEBPROGRESSLISTENER2_ONREFRESHATTEMPTED
+/* boolean onRefreshAttempted (in nsIWebProgress aWebProgress, in nsIURI aRefreshURI, in long aMillis, in boolean aSameURI); */
+NS_IMETHODIMP GProgressListener::
+			OnRefreshAttempted(nsIWebProgress *aWebProgress,
+					   nsIURI *aRefreshURI, PRInt32 aMillis,
+					   PRBool aSameURI, PRBool *_retval)
+{
+    *_retval = PR_TRUE;
+    return NS_OK;
+}
+#endif
+
 //---------------------------------------------------------------------------
 NS_METHOD GProgressListener::SetRequest (nsIRequest *aRequest)
 {
