@@ -19,10 +19,6 @@
 #ifndef gUrlCID_h__
 #define gUrlCID_h__
 
-#include "nsISupports.h"
-#include "nsIFactory.h"
-#include "nsIComponentManager.h"
-
 //
 // nsMailtoUrl
 //
@@ -36,16 +32,4 @@
  0x5bab5e7, 0x9c7d, 0x11d3,                         \
  {0x98, 0xa3, 0x0, 0x10, 0x83, 0x1, 0xe, 0x9b}}
 
-#define G_GNOMEHELPURL_CLASSNAME \
-    "Gnome Help URI"
-#define G_GNOMEHELPURL_CONTRACTID \
-    "@gnome.org/network/help-uri;1"
-#define G_GNOMEHELPURL_CID                              \
-{ /* e0da1d70-2f7b-11d3-8cd0-0060b0fc14a3 */          \
-     0xe0da1d70,                                      \
-     0x2f7b,                                          \
-     0x11d3,                                          \
-     {0x8c, 0xd0, 0x00, 0x60, 0xb0, 0xfc, 0x14, 0xa4} \
-}
-
 #endif // gUrlCID_h__
