@@ -139,7 +139,11 @@ conversion_table [] =
 {
 	{ CONF_FILTERING_JAVA_ENABLED, BOOL_PREF, "security.enable_java"},
 	{ CONF_FILTERING_JAVASCRIPT_ENABLED, BOOL_PREF, "javascript.enabled"},
+#ifdef HAVE_NEW_IMAGE_PERMISSION_NAME
+	{ CONF_FILTERING_IMAGE_LOADING_TYPE, INT_PREF, "permissions.default.image"},
+#else
 	{ CONF_FILTERING_IMAGE_LOADING_TYPE, INT_PREF, "network.image.imageBehavior"},
+#endif
 	{ CONF_RENDERING_BG_COLOR, STRING_PREF, "browser.display.background_color"},
 	{ CONF_RENDERING_TEXT_COLOR, STRING_PREF, "browser.display.foreground_color"},
 	{ CONF_RENDERING_UNVISITED_LINKS, STRING_PREF, "browser.anchor_color"},
