@@ -34,15 +34,18 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
+#define MOZILLA_INTERNAL_API
+#include <nsString.h>
+#include <nsIComponentManager.h>
+#include <nsReadableUtils.h>
+#include <nsEscape.h>
+#undef MOZILLA_INTERNAL_API
+
 #include "nsMailtoUrl.h"
 
 #include <nsIURI.h>
 #include <nsNetCID.h>
-#include <nsString.h>
 #include <nsCRT.h>
-#include <nsReadableUtils.h>
-#include <nsEscape.h>
-#include <nsIComponentManager.h>
 
 static NS_DEFINE_CID(kSimpleURICID, NS_SIMPLEURI_CID);
 
