@@ -649,10 +649,11 @@ galeon_find_toolbar_set_embed (GaleonFindToolbar *toolbar,
 void
 galeon_find_toolbar_find_next (GaleonFindToolbar *toolbar)
 {
+	GaleonFindToolbarPrivate *priv = toolbar->priv;
 	GaleonEmbedFindResult result;
 	gboolean found;
 
-	result = galeon_embed_find_find_again (get_find (toolbar), TRUE);
+	result = galeon_embed_find_find_again (get_find (toolbar), TRUE, priv->links_only);
 
 	found = result != GALEON_EMBED_FIND_NOTFOUND;
 	set_controls (toolbar, found, found);
@@ -662,10 +663,11 @@ galeon_find_toolbar_find_next (GaleonFindToolbar *toolbar)
 void
 galeon_find_toolbar_find_previous (GaleonFindToolbar *toolbar)
 {
+	GaleonFindToolbarPrivate *priv = toolbar->priv;
 	GaleonEmbedFindResult result;
 	gboolean found;
 
-	result = galeon_embed_find_find_again (get_find (toolbar), FALSE);
+	result = galeon_embed_find_find_again (get_find (toolbar), FALSE, priv->links_only);
 	found = result != GALEON_EMBED_FIND_NOTFOUND;
 	set_controls (toolbar, found, found);
 	set_status (toolbar, result);
