@@ -884,7 +884,8 @@ galeon_tab_set_title (GaleonTab *tab, const char* title)
 	if (*(tab->priv->title) == '\0')
 	{
 		g_free (tab->priv->title);
-		if (!strcmp (tab->priv->location, "about:blank"))
+		if (!tab->priv->location ||
+		    !strcmp (tab->priv->location, "about:blank"))
 		{
 			tab->priv->title = g_strdup(_("Untitled"));
 		}
