@@ -36,6 +36,7 @@
 #include <gtk/gtkstock.h>
 #include <gtk/gtkentry.h>
 #include <gtk/gtklabel.h>
+#include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
 
 #define get_filter_from_treeview(treeview) \
@@ -896,6 +897,26 @@ pdm_dialog_remove_button_clicked_cb (GtkWidget *button,
 	}
 }
 
+static gboolean
+pdm_key_pressed_cb (GtkTreeView *treeview,
+		    GdkEventKey *event,
+		    PdmActionInfo *action)
+{
+	if (event->keyval == GDK_Delete || event->keyval == GDK_KP_Delete)
+	{
+		GList *remove_list = get_remove_list(action);
+		if (remove_list)
+		{
+			action->remove (action, remove_list);
+			action->free (action, remove_list);
+		}
+
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
 static void
 setup_action (PdmActionInfo *action)
 {
@@ -920,6 +941,11 @@ setup_action (PdmActionInfo *action)
 			  G_CALLBACK(action_treeview_selection_changed_cb),
 			  action);
 
+	g_signal_connect (G_OBJECT (action->treeview),
+			  "key_press_event",
+			  G_CALLBACK (pdm_key_pressed_cb),
+			  action);
+
 	filter = get_filter_from_treeview(action->treeview);
 	gtk_tree_model_filter_set_visible_func(filter, visibility_filter_func,
 					       action, NULL);
