@@ -110,7 +110,7 @@ galeon_dnd_drag_data_get (GtkWidget *widget,
         
         gtk_selection_data_set (selection_data,
                                 selection_data->target,
-                                8, result->str, result->len);
+                                8, (guchar*)result->str, result->len);
 
 	g_string_free (result, TRUE);
 
@@ -138,7 +138,7 @@ galeon_dnd_drag_data_receive (GtkWidget *widget,
 			      gpointer container_context,
 			      GaleonDragEachReceivedItemIterator each_received_item_iterator)
 {
-	char * data = selection_data->data;
+	char * data = (char*)selection_data->data;
 
 	if (widget) g_signal_stop_emission_by_name (widget, "drag_data_received");
 
