@@ -26,11 +26,11 @@ G_BEGIN_DECLS
 
 typedef struct GulNotebookClass GulNotebookClass;
 
-#define GUL_NOTEBOOK_TYPE             (gul_notebook_get_type ())
-#define GUL_NOTEBOOK(obj)             (GTK_CHECK_CAST ((obj), GUL_NOTEBOOK_TYPE, GulNotebook))
-#define GUL_NOTEBOOK_CLASS(klass)     (GTK_CHECK_CLASS_CAST ((klass), GUL_NOTEBOOK_TYPE, GulNotebookClass))
-#define IS_GUL_NOTEBOOK(obj)          (GTK_CHECK_TYPE ((obj), GUL_NOTEBOOK_TYPE))
-#define IS_GUL_NOTEBOOK_CLASS(klass)  (GTK_CHECK_CLASS_TYPE ((klass), GUL_NOTEBOOK))
+#define GUL_TYPE_NOTEBOOK             (gul_notebook_get_type ())
+#define GUL_NOTEBOOK(obj)             (GTK_CHECK_CAST ((obj), GUL_TYPE_NOTEBOOK, GulNotebook))
+#define GUL_NOTEBOOK_CLASS(klass)     (GTK_CHECK_CLASS_CAST ((klass), GUL_TYPE_NOTEBOOK, GulNotebookClass))
+#define GUL_IS_NOTEBOOK(obj)          (GTK_CHECK_TYPE ((obj), GUL_TYPE_NOTEBOOK))
+#define GUL_IS_NOTEBOOK_CLASS(klass)  (GTK_CHECK_CLASS_TYPE ((klass), GUL_NOTEBOOK))
 
 typedef struct GulNotebook GulNotebook;
 typedef struct GulNotebookPrivate GulNotebookPrivate;
@@ -52,14 +52,21 @@ struct GulNotebookClass
         GtkNotebookClass parent_class;
 
 	/* Signals */
-	void (* tab_dropped)       (GulNotebook *dest,
-				    GtkWidget *widget,
-				    GulNotebook *src,
-				    gint src_page);
+	void (* tab_added)	   (GulNotebook *notebook,
+				    GtkWidget *child);
+
+	void (* tab_removed)	   (GulNotebook *notebook,
+				    GtkWidget *child);
+
+	void (* tabs_reordered)	   (GulNotebook *notebook);
+
 	void (* tab_detached)      (GulNotebook *dest,
 				    gint cur_page,
 				    gint root_x, gint root_y);
 
+	void (* tab_delete)        (GulNotebook *dest,
+				    GtkWidget *child);
+
 };
 
 GType 		gul_notebook_get_type 		(void);
@@ -90,6 +97,10 @@ void		gul_notebook_set_page_title 	(GulNotebook *nb,
 void		gul_notebook_set_policy		(GulNotebook *nb,
 		                                 GtkPolicyType policy);
 
+void		gul_notebook_set_page_icon	(GulNotebook *nb,
+						 GtkWidget *child,
+						 GtkWidget *icon);
+
 G_END_DECLS
 
 #endif /* GUL_NOTEBOOK_H */
